pub struct ApprovalQueue { /* private fields */ }Expand description
FIFO queue for pending permission and question approvals.
Implementations
Sourceimpl ApprovalQueue
impl ApprovalQueue
pub fn new() -> Self
Sourcepub fn has_pending(&self) -> bool
pub fn has_pending(&self) -> bool
Returns true if there are pending items.
Sourcepub fn peek(&self) -> Option<&PendingApproval>
pub fn peek(&self) -> Option<&PendingApproval>
Returns a reference to the front item without removing it.
Sourcepub fn add_permission(&mut self, request: PermissionRequest)
pub fn add_permission(&mut self, request: PermissionRequest)
Adds a permission request to the back of the queue.
Sourcepub fn add_question(&mut self, request: QuestionRequest)
pub fn add_question(&mut self, request: QuestionRequest)
Adds a question request to the back of the queue.