Module state

Module state 

Core state and event types for the voice application.

Enums

AppEvent
Application-wide events flowing through the main event loop channel.
InputEvent
Input events from keyboard or global hotkey.
RecordingState
The recording state machine.