pub enum AppEvent {
Input(InputEvent),
SseConnected,
SseDisconnected(Option<String>),
PermissionAsked(PermissionRequest),
PermissionReplied {
session_id: String,
request_id: String,
reply: String,
},
QuestionAsked(QuestionRequest),
QuestionReplied {
session_id: String,
request_id: String,
answers: Vec<Vec<String>>,
},
QuestionRejected {
session_id: String,
request_id: String,
},
SessionStatus {
session_id: String,
busy: bool,
},
AudioChunk {
rms_energy: f32,
},
RecoverFromError,
Shutdown,
}Expand description
Application-wide events flowing through the main event loop channel.
Variants
Input(InputEvent)
SseConnected
SseDisconnected(Option<String>)
PermissionAsked(PermissionRequest)
PermissionReplied
QuestionAsked(QuestionRequest)
QuestionReplied
QuestionRejected
SessionStatus
Session status changed (busy/idle).
Used to detect when the AI resumes work — implying any pending approvals have been answered (possibly manually by the user).
AudioChunk
RecoverFromError
Sent after a 3-second delay to transition back to Idle from Error state.
Shutdown