Core state and event types for the voice application.
Enums
- AppEvent
- Application-wide events flowing through the main event loop channel.
- Input
Event - Input events from keyboard or global hotkey.
- Recording
State - The recording state machine.